@@ -28,7 +28,7 @@ pub struct NSTDHeap {
 /// Returns: `NSTDByte *ptr` - The new memory block.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_alloc_allocate(size: usize) -> *mut u8 {
+pub unsafe extern "C" fn nstd_alloc_allocate(size: usize) -> *mut u8 {
     platform::allocate(size)
 }
 
@@ -38,7 +38,7 @@ pub unsafe extern "C" fn nstd_std_alloc_allocate(size: usize) -> *mut u8 {
 /// Returns: `NSTDByte *ptr` - The new memory block.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_alloc_allocate_zeroed(size: usize) -> *mut u8 {
+pub unsafe extern "C" fn nstd_alloc_allocate_zeroed(size: usize) -> *mut u8 {
     platform::allocate_zeroed(size)
 }
 
@@ -50,7 +50,7 @@ pub unsafe extern "C" fn nstd_std_alloc_allocate_zeroed(size: usize) -> *mut u8
 /// Returns: `int errc` - Nonzero on error.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_alloc_reallocate(
+pub unsafe extern "C" fn nstd_alloc_reallocate(
     ptr: *mut *mut u8,
     size: usize,
     new_size: usize,
@@ -65,7 +65,7 @@ pub unsafe extern "C" fn nstd_std_alloc_reallocate(
 /// Returns: `int errc` - Nonzero on error.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_alloc_deallocate(ptr: *mut *mut u8, size: usize) -> c_int {
+pub unsafe extern "C" fn nstd_alloc_deallocate(ptr: *mut *mut u8, size: usize) -> c_int {
     platform::deallocate(ptr, size)
 }
 
@@ -74,9 +74,9 @@ pub unsafe extern "C" fn nstd_std_alloc_deallocate(ptr: *mut *mut u8, size: usiz
 ///     `const NSTDPointer *const ptr` - Pointer to an object to be copied to the heap.
 /// Returns: `NSTDHeap obj` - The new heap allocated object.
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_alloc_heap_new(ptr: &NSTDPointer) -> NSTDHeap {
+pub unsafe extern "C" fn nstd_alloc_heap_new(ptr: &NSTDPointer) -> NSTDHeap {
     let ptr_slice = core::slice::from_raw_parts(ptr.ptr as *const u8, ptr.size);
-    let alloc = nstd_std_alloc_allocate(ptr.size);
+    let alloc = nstd_alloc_allocate(ptr.size);
     if !alloc.is_null() {
         let alloc_slice = core::slice::from_raw_parts_mut(alloc, ptr.size);
         alloc_slice.copy_from_slice(ptr_slice);
@@ -92,7 +92,7 @@ pub unsafe extern "C" fn nstd_std_alloc_heap_new(ptr: &NSTDPointer) -> NSTDHeap
 /// Returns: `int errc` - Nonzero on error.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_alloc_heap_free(obj: &mut NSTDHeap) -> c_int {
+pub unsafe extern "C" fn nstd_alloc_heap_free(obj: &mut NSTDHeap) -> c_int {
     let ptr = addr_of_mut!(obj.ptr.ptr) as *mut *mut u8;
-    nstd_std_alloc_deallocate(ptr, obj.ptr.size)
+    nstd_alloc_deallocate(ptr, obj.ptr.size)
 }
